fnss.topologies.simplemodels.star_topology — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.topologies.simplemodels.star_topology

`star_topology`(n)

  Return a line topology of n+1 nodes

  The root node has id 0 while all leaf nodes have id (1, n + 1).

  Each node has the attribute type which can either be “root” (for node 0) or “leaf” for all other nodes

  Parameters : | n : int The number of leaf nodes
  Returns : | topology : A Topology object

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »